# Spack Environments

This folder contains spack environments for various computers which should be
able to compile the models offered in the esm-tools toolbox. Please note,
however, that these are only here for reference and that we recommend you to
use `esm-master` to install your models!
